pub struct BucketHead<C> {
pub signature: u64,
pub size: u64,
pub have_to_return_data: bool,
pub command: C,
pub return_code: i32,
pub flags: Flags,
pub protocol_version: u32,
}Expand description
The Header of a Bucket. This contains
Fields
signature: u64The network signature, should be LEVIN_SIGNATURE for Monero
size: u64The size of the body
have_to_return_data: boolIf the peer has to send data in the order of requests - some messages require responses but don’t have this set (some notifications)
command: CCommand
return_code: i32Return Code - will be 0 for requests and >0 for ok responses otherwise will be a negative number corresponding to the error
flags: FlagsThe Flags of this header
protocol_version: u32The protocol version, for Monero this is currently 1
Implementations
Sourceimpl<C: LevinCommand> BucketHead<C>
impl<C: LevinCommand> BucketHead<C>
Sourcepub fn from_bytes(buf: &mut BytesMut) -> Self
pub fn from_bytes(buf: &mut BytesMut) -> Self
Builds the header from bytes, this function does not check any fields should match the expected ones.
Panics
This function will panic if there aren’t enough bytes to fill the header.
Currently HEADER_SIZE
Sourcepub fn write_bytes_into(&self, dst: &mut BytesMut)
pub fn write_bytes_into(&self, dst: &mut BytesMut)
Serializes the header